==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_functions/gridrequest/PROMPTFIELD.java <==

package net.datastream.schemas.mp_functions.gridrequest;

import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;attribute name="TRANSACTIONTYPE" type="{http://schemas.datastream.net/MP_fields}CODE4_Type" />
 *       &lt;attribute name="WSPROMPTCODE" type="{http://schemas.datastream.net/MP_fields}CODE6_Type" />
 *       &lt;attribute name="SOURCEPROMPTSEQUENCE" type="{http://www.w3.org/2001/XMLSchema}integer" />
 *       &lt;attribute name="TARGETPROMPTSEQUENCE" type="{http://www.w3.org/2001/XMLSchema}integer" />
 *       &lt;attribute name="NUMBER_OF_ROWS_FIRST_RETURNED" type="{http://www.w3.org/2001/XMLSchema}integer" />
 *       &lt;attribute name="CURSOR_POSITION" type="{http://schemas.datastream.net/MP_functions/GridRequest}CURSOR_POSITION" />
 *       &lt;attribute name="TERSERESPONSE" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "PROMPTFIELD")
public class PROMPTFIELD {

    @XmlAttribute(name = "TRANSACTIONTYPE")
    protected String transactiontype;
    @XmlAttribute(name = "WSPROMPTCODE")
    protected String wspromptcode;
    @XmlAttribute(name = "SOURCEPROMPTSEQUENCE")
    protected BigInteger sourcepromptsequence;
    @XmlAttribute(name = "TARGETPROMPTSEQUENCE")
    protected BigInteger targetpromptsequence;
    @XmlAttribute(name = "NUMBER_OF_ROWS_FIRST_RETURNED")
    protected BigInteger number_OF_ROWS_FIRST_RETURNED;
    @XmlAttribute(name = "CURSOR_POSITION")
    protected BigInteger cursor_POSITION;
    @XmlAttribute(name = "TERSERESPONSE")
    protected String terseresponse;

    /**
     * Gets the value of the transactiontype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTRANSACTIONTYPE() {
        return transactiontype;
    }

    /**
     * Sets the value of the transactiontype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTRANSACTIONTYPE(String value) {
        this.transactiontype = value;
    }

    /**
     * Gets the value of the wspromptcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWSPROMPTCODE() {
        return wspromptcode;
    }

    /**
     * Sets the value of the wspromptcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWSPROMPTCODE(String value) {
        this.wspromptcode = value;
    }

    /**
     * Gets the value of the sourcepromptsequence property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getSOURCEPROMPTSEQUENCE() {
        return sourcepromptsequence;
    }

    /**
     * Sets the value of the sourcepromptsequence property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setSOURCEPROMPTSEQUENCE(BigInteger value) {
        this.sourcepromptsequence = value;
    }

    /**
     * Gets the value of the targetpromptsequence property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getTARGETPROMPTSEQUENCE() {
        return targetpromptsequence;
    }

    /**
     * Sets the value of the targetpromptsequence property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setTARGETPROMPTSEQUENCE(BigInteger value) {
        this.targetpromptsequence = value;
    }

    /**
     * Gets the value of the number_OF_ROWS_FIRST_RETURNED property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getNUMBER_OF_ROWS_FIRST_RETURNED() {
        return number_OF_ROWS_FIRST_RETURNED;
    }

    /**
     * Sets the value of the number_OF_ROWS_FIRST_RETURNED property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setNUMBER_OF_ROWS_FIRST_RETURNED(BigInteger value) {
        this.number_OF_ROWS_FIRST_RETURNED = value;
    }

    /**
     * Gets the value of the cursor_POSITION property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getCURSOR_POSITION() {
        return cursor_POSITION;
    }

    /**
     * Sets the value of the cursor_POSITION property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setCURSOR_POSITION(BigInteger value) {
        this.cursor_POSITION = value;
    }

    /**
     * Gets the value of the terseresponse property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTERSERESPONSE() {
        return terseresponse;
    }

    /**
     * Sets the value of the terseresponse property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTERSERESPONSE(String value) {
        this.terseresponse = value;
    }

}

==> eam-wshub-proxyclient-11.5-3-sources.jar: net/datastream/schemas/mp_functions/gridrequest/PROMPTFIELD.java <==

package net.datastream.schemas.mp_functions.gridrequest;

import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;attribute name="TRANSACTIONTYPE" type="{http://schemas.datastream.net/MP_fields}CODE4_Type" />
 *       &lt;attribute name="WSPROMPTCODE" type="{http://schemas.datastream.net/MP_fields}CODE6_Type" />
 *       &lt;attribute name="SOURCEPROMPTSEQUENCE" type="{http://www.w3.org/2001/XMLSchema}integer" />
 *       &lt;attribute name="TARGETPROMPTSEQUENCE" type="{http://www.w3.org/2001/XMLSchema}integer" />
 *       &lt;attribute name="NUMBER_OF_ROWS_FIRST_RETURNED" type="{http://www.w3.org/2001/XMLSchema}integer" />
 *       &lt;attribute name="CURSOR_POSITION" type="{http://schemas.datastream.net/MP_functions/GridRequest}CURSOR_POSITION" />
 *       &lt;attribute name="TERSERESPONSE" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "PROMPTFIELD")
public class PROMPTFIELD {

    @XmlAttribute(name = "TRANSACTIONTYPE")
    protected String transactiontype;
    @XmlAttribute(name = "WSPROMPTCODE")
    protected String wspromptcode;
    @XmlAttribute(name = "SOURCEPROMPTSEQUENCE")
    protected BigInteger sourcepromptsequence;
    @XmlAttribute(name = "TARGETPROMPTSEQUENCE")
    protected BigInteger targetpromptsequence;
    @XmlAttribute(name = "NUMBER_OF_ROWS_FIRST_RETURNED")
    protected BigInteger number_OF_ROWS_FIRST_RETURNED;
    @XmlAttribute(name = "CURSOR_POSITION")
    protected BigInteger cursor_POSITION;
    @XmlAttribute(name = "TERSERESPONSE")
    protected String terseresponse;

    /**
     * Obtient la valeur de la propriété transactiontype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTRANSACTIONTYPE() {
        return transactiontype;
    }

    /**
     * Définit la valeur de la propriété transactiontype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTRANSACTIONTYPE(String value) {
        this.transactiontype = value;
    }

    /**
     * Obtient la valeur de la propriété wspromptcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWSPROMPTCODE() {
        return wspromptcode;
    }

    /**
     * Définit la valeur de la propriété wspromptcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWSPROMPTCODE(String value) {
        this.wspromptcode = value;
    }

    /**
     * Obtient la valeur de la propriété sourcepromptsequence.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getSOURCEPROMPTSEQUENCE() {
        return sourcepromptsequence;
    }

    /**
     * Définit la valeur de la propriété sourcepromptsequence.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setSOURCEPROMPTSEQUENCE(BigInteger value) {
        this.sourcepromptsequence = value;
    }

    /**
     * Obtient la valeur de la propriété targetpromptsequence.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getTARGETPROMPTSEQUENCE() {
        return targetpromptsequence;
    }

    /**
     * Définit la valeur de la propriété targetpromptsequence.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setTARGETPROMPTSEQUENCE(BigInteger value) {
        this.targetpromptsequence = value;
    }

    /**
     * Obtient la valeur de la propriété number_OF_ROWS_FIRST_RETURNED.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getNUMBER_OF_ROWS_FIRST_RETURNED() {
        return number_OF_ROWS_FIRST_RETURNED;
    }

    /**
     * Définit la valeur de la propriété number_OF_ROWS_FIRST_RETURNED.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setNUMBER_OF_ROWS_FIRST_RETURNED(BigInteger value) {
        this.number_OF_ROWS_FIRST_RETURNED = value;
    }

    /**
     * Obtient la valeur de la propriété cursor_POSITION.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getCURSOR_POSITION() {
        return cursor_POSITION;
    }

    /**
     * Définit la valeur de la propriété cursor_POSITION.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setCURSOR_POSITION(BigInteger value) {
        this.cursor_POSITION = value;
    }

    /**
     * Obtient la valeur de la propriété terseresponse.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTERSERESPONSE() {
        return terseresponse;
    }

    /**
     * Définit la valeur de la propriété terseresponse.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTERSERESPONSE(String value) {
        this.terseresponse = value;
    }

}
